@@ -15,10 +15,11 @@ from rest_in_peace_gui import *
 
 class MyForm(QtGui.QMainWindow):
     def __init__(self, parent=None):
-        self.enableLogging = False;
-        self.enableAlarm = True;
-        self.enableGSMAlarm = False;
-        self.searchCellID = None;  #modified when you choose a favorite. This variable holds the match the system searches for
+        self.enableLogging = False
+        self.enableAlarm = True
+        self.enableGSMAlarm = False
+        self.searchCellID = None
+        self.selected_group = None
 
         self.cellID_list_changed=False
 
@@ -45,7 +46,7 @@ class MyForm(QtGui.QMainWindow):
 #        QtCore.QObject.connect(self.ui.checkBoxAlarm, QtCore.SIGNAL('stateChanged(int)'), self.setAlarm)
         QtCore.QObject.connect(self.ui.checkBoxGSMAlarm, QtCore.SIGNAL('stateChanged(int)'), self.setGSMAlarm)
         QtCore.QObject.connect(self.ui.checkBoxLogging, QtCore.SIGNAL('stateChanged(int)'), self.setLogging)
-        QtCore.QObject.connect(self.ui.comboBoxFav, QtCore.SIGNAL('currentIndexChanged(QString)'), self.changeCellID)
+        QtCore.QObject.connect(self.ui.comboBoxFav, QtCore.SIGNAL('currentIndexChanged(QString)'), self.select_group)
         QtCore.QObject.connect(self.ui.comboBoxFav, QtCore.SIGNAL('editTextChanged(QString)'), self.enableSaveButton)
         QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), self.closeEvent)
         QtCore.QObject.connect(self.ui.actionMenuAbout, QtCore.SIGNAL('triggered()'), self.showAbout)
@@ -75,8 +76,7 @@ class MyForm(QtGui.QMainWindow):
         QtCore.QCoreApplication.setOrganizationName('Rest In Peace')
         QtCore.QCoreApplication.setOrganizationDomain('Rest In Peace')
         QtCore.QCoreApplication.setApplicationName('Rest In Peace')
-        settings = QtCore.QSettings()
-        self.settings = settings
+        self.settings = QtCore.QSettings()
 
     def load_settings(self):
         # check to see if there is a save file
@@ -99,12 +99,13 @@ class MyForm(QtGui.QMainWindow):
 
 
     def doStart(self):
-        self.ui.pushButtonStart.setText("Waiting for a CellID from [" + str(self.ui.comboBoxFav.currentText()) + "] group.\nClick again to set new destination.")
+        if self.cellID_list.__contains__(str(self.selected_group)):
+            self.searchCellID = self.cellID_list[str(self.selected_group)]
+            self.ui.pushButtonStart.setText("Waiting for a CellID from [" + str(self.ui.comboBoxFav.currentText()) + "] group.\nClick again to set new destination.")
 
     # Change the CellID to search for when User hits "go"
-    def changeCellID(self, favorite):
-        if self.cellID_list.__contains__(str(favorite)):
-            self.searchCellID = self.cellID_list[str(favorite)]
+    def select_group(self, group):
+        self.selected_group = group
 
     # Enable button when user modifies the text in the comboBox
     # just to give some feedback that the two controls are linked
@@ -148,16 +149,20 @@ class MyForm(QtGui.QMainWindow):
             return
         self.cellID_list_changed=True
         print "OK"
+        self.update_name()
 
     def update_name(self):
         self.ui.spinBoxCellID.setSuffix("")
+        self.cellID_name = ""
         self.ui.spinBoxCellID.setValue(self.current_cellid)
         for key in self.cellID_list.iterkeys():
             if self.cellID_list[key].__contains__(self.current_cellid):
-                self.cellID_name = key
-                break
-        self.ui.spinBoxCellID.setSuffix(": "+self.cellID_name)
-
+                if self.cellID_name:
+                    self.cellID_name += ", " + key
+                else:
+                    self.cellID_name = key
+        if self.cellID_name:
+            self.ui.spinBoxCellID.setSuffix(": "+self.cellID_name)
 
     def closeEvent(self, event):
         #Save settings
@@ -202,6 +207,7 @@ class MyForm(QtGui.QMainWindow):
             if not(sub_proceed): continue
             if sub_selected_item == delete_group_text:
                 self.cellID_list.pop(selected_item)
+                self.cellID_list_changed = True
                 sub_proceed = False
                 continue
             try:
